==> jc-1.4.0.tar.gz: gnu/java/beans/decoder/AbstractCreatableObjectContext.h <==
// abstract class gnu.java.beans.decoder.AbstractCreatableObjectContext

// class file dependencies
// @dep_class f38552320b706ae7 gnu_java_beans_decoder_AbstractContext
// @dep_class 3a61d506f2f71ad8 gnu_java_beans_decoder_AbstractCreatableObjectContext
// @dep_class ea23baef93420b4f gnu_java_beans_decoder_AbstractObjectContext
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_java_beans_decoder_AbstractObjectContext

#include "gnu/java/beans/decoder/AbstractObjectContext.h"

#ifndef _JC_gnu_java_beans_decoder_AbstractCreatableObjectContext_H_
#define _JC_gnu_java_beans_decoder_AbstractCreatableObjectContext_H_

// Forward structure declarations
struct _jc_gnu_java_beans_decoder_Context$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$sub_refs	_jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$sub_refs;
typedef struct _jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$sub_nonrefs	_jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$sub_nonrefs;
typedef struct _jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$refs	_jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$refs;
typedef struct _jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$nonrefs	_jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$nonrefs;
typedef struct _jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$object	_jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$object;

typedef const struct _jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$vmethods	_jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$vmethods;
typedef const struct _jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$vtable	_jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$vtable;
typedef const struct _jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$vtype	_jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$vtype;

// Constructors
extern void _jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$object *);

// Virtual methods
extern void _jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$method$addParameterObject$4706d521eeccfb00(_jc_env *, struct _jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$object *, struct _jc_java_lang_Object$object *);
extern void _jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$method$addParameterObjectImpl$a6c333697c3baaa7(_jc_env *, struct _jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_java_lang_Object$object *_jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$method$createObject$bd62db7229823e1e(_jc_env *, struct _jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$method$endContext$404ed46ecd22657f(_jc_env *, struct _jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$object *, struct _jc_object *);
extern void _jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$method$notifyStatement$516a25c30df0911b(_jc_env *, struct _jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$object *, struct _jc_object *);
extern jboolean _jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$method$subContextFailed$dac667c9783c2a33(_jc_env *, struct _jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$method_info$addParameterObject$4706d521eeccfb00;
extern _jc_method _jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$method_info$addParameterObjectImpl$a6c333697c3baaa7;
extern _jc_method _jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$method_info$createObject$bd62db7229823e1e;
extern _jc_method _jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$method_info$endContext$404ed46ecd22657f;
extern _jc_method _jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$method_info$notifyStatement$516a25c30df0911b;
extern _jc_method _jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$method_info$subContextFailed$dac667c9783c2a33;

// Virtual methods structure
struct _jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$vmethods {
	void	(*addParameterObject$4706d521eeccfb00)(_jc_env *, struct _jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$object *, struct _jc_java_lang_Object$object *);
	void	(*addParameterObjectImpl$a6c333697c3baaa7)(_jc_env *, struct _jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$object *, struct _jc_java_lang_Object$object *);
	struct _jc_java_lang_Object$object	*(*createObject$bd62db7229823e1e)(_jc_env *, struct _jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*endContext$404ed46ecd22657f)(_jc_env *, struct _jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$object *, struct _jc_object *);
	void	(*notifyStatement$516a25c30df0911b)(_jc_env *, struct _jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$object *, struct _jc_object *);
	jboolean	(*subContextFailed$dac667c9783c2a33)(_jc_env *, struct _jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$object *);
};

// Vtable
struct _jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_beans_decoder_AbstractContext$vmethods	gnu_java_beans_decoder_AbstractContext;
	_jc_gnu_java_beans_decoder_AbstractObjectContext$vmethods	gnu_java_beans_decoder_AbstractObjectContext;
	_jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$vmethods	gnu_java_beans_decoder_AbstractCreatableObjectContext;
};

// Vtype
struct _jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$vtype {
	_jc_type			type;
	_jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$refs {
    _jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$sub_refs	gnu_java_beans_decoder_AbstractCreatableObjectContext;
    _jc_gnu_java_beans_decoder_AbstractObjectContext$sub_refs	gnu_java_beans_decoder_AbstractObjectContext;
    _jc_gnu_java_beans_decoder_AbstractContext$sub_refs	gnu_java_beans_decoder_AbstractContext;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_beans_decoder_AbstractContext$sub_nonrefs	gnu_java_beans_decoder_AbstractContext;
    _jc_gnu_java_beans_decoder_AbstractObjectContext$sub_nonrefs	gnu_java_beans_decoder_AbstractObjectContext;
    _jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$sub_nonrefs	gnu_java_beans_decoder_AbstractCreatableObjectContext;
};

// Object instance structure
struct _jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$object {
	_jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$vtype	*vtype;
	_jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$vtype _jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_beans_decoder_AbstractCreatableObjectContext, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$class_object;

#endif	/* _JC_gnu_java_beans_decoder_AbstractCreatableObjectContext_H_ */

==> jc-1.4.6.tar.gz: gnu/java/beans/decoder/AbstractCreatableObjectContext.h <==
// abstract class gnu.java.beans.decoder.AbstractCreatableObjectContext

// class file dependencies
// @dep_class f38552320b706ae7 gnu_java_beans_decoder_AbstractContext
// @dep_class 3a61d506f2f71ad8 gnu_java_beans_decoder_AbstractCreatableObjectContext
// @dep_class ea23baef93420b4f gnu_java_beans_decoder_AbstractObjectContext
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_java_beans_decoder_AbstractObjectContext

#include "gnu/java/beans/decoder/AbstractObjectContext.h"

#ifndef _JC_gnu_java_beans_decoder_AbstractCreatableObjectContext_H_
#define _JC_gnu_java_beans_decoder_AbstractCreatableObjectContext_H_

// Forward structure declarations
struct _jc_gnu_java_beans_decoder_Context$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$sub_refs	_jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$sub_refs;
typedef struct _jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$sub_nonrefs	_jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$sub_nonrefs;
typedef struct _jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$refs	_jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$refs;
typedef struct _jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$nonrefs	_jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$nonrefs;
typedef struct _jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$object	_jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$object;

typedef const struct _jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$vmethods	_jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$vmethods;
typedef const struct _jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$vtable	_jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$vtable;
typedef const struct _jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$vtype	_jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$vtype;

// Constructors
extern void _jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$method$addParameterObject$4706d521eeccfb00(_jc_env *, struct _jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$method$addParameterObjectImpl$a6c333697c3baaa7(_jc_env *, struct _jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$method$createObject$bd62db7229823e1e(_jc_env *, struct _jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$method$endContext$404ed46ecd22657f(_jc_env *, struct _jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$method$notifyStatement$516a25c30df0911b(_jc_env *, struct _jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern jboolean _jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$method$subContextFailed$dac667c9783c2a33(_jc_env *, struct _jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$method_info$addParameterObject$4706d521eeccfb00;
extern _jc_method _jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$method_info$addParameterObjectImpl$a6c333697c3baaa7;
extern _jc_method _jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$method_info$createObject$bd62db7229823e1e;
extern _jc_method _jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$method_info$endContext$404ed46ecd22657f;
extern _jc_method _jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$method_info$notifyStatement$516a25c30df0911b;
extern _jc_method _jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$method_info$subContextFailed$dac667c9783c2a33;

// Virtual methods structure
struct _jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$vmethods {
	void	(*addParameterObject$4706d521eeccfb00)(_jc_env *, struct _jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	void	(*addParameterObjectImpl$a6c333697c3baaa7)(_jc_env *, struct _jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*createObject$bd62db7229823e1e)(_jc_env *, struct _jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*endContext$404ed46ecd22657f)(_jc_env *, struct _jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*notifyStatement$516a25c30df0911b)(_jc_env *, struct _jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$object *, struct _jc_object *) _JC_JCNI_ATTR;
	jboolean	(*subContextFailed$dac667c9783c2a33)(_jc_env *, struct _jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_beans_decoder_AbstractContext$vmethods	gnu_java_beans_decoder_AbstractContext;
	_jc_gnu_java_beans_decoder_AbstractObjectContext$vmethods	gnu_java_beans_decoder_AbstractObjectContext;
	_jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$vmethods	gnu_java_beans_decoder_AbstractCreatableObjectContext;
};

// Vtype
struct _jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$vtype {
	_jc_type			type;
	_jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$refs {
    _jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$sub_refs	gnu_java_beans_decoder_AbstractCreatableObjectContext;
    _jc_gnu_java_beans_decoder_AbstractObjectContext$sub_refs	gnu_java_beans_decoder_AbstractObjectContext;
    _jc_gnu_java_beans_decoder_AbstractContext$sub_refs	gnu_java_beans_decoder_AbstractContext;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_beans_decoder_AbstractContext$sub_nonrefs	gnu_java_beans_decoder_AbstractContext;
    _jc_gnu_java_beans_decoder_AbstractObjectContext$sub_nonrefs	gnu_java_beans_decoder_AbstractObjectContext;
    _jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$sub_nonrefs	gnu_java_beans_decoder_AbstractCreatableObjectContext;
};

// Object instance structure
struct _jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$object {
	_jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$vtype	*vtype;
	_jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$vtype _jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_beans_decoder_AbstractCreatableObjectContext, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$class_object;

#endif	/* _JC_gnu_java_beans_decoder_AbstractCreatableObjectContext_H_ */
